@@ -52,7 +52,7 @@ sub pid {
     return $$;
 }
 
-sub ten_childs {
+sub ten_processes {
     my ( $self, $job, $workload ) = @_;
     return $self->pid;
 }
@@ -64,4 +64,4 @@ sub sleeper {
     return time - $time;
 }
 
-1;
\ No newline at end of file
+1;
